/**
 * @fileoverview Module contains the function for building a Shader.
 */
import { AttributeData, Attribute } from './attributes';
import { Viewport } from './gl';
import { TextureUniform, TextureData, Uniform, UniformData } from './uniforms';
/**
 * Interface for the options you can supply to Shader.
 */
export interface ShaderOptions {
    attributes: Attribute<AttributeData>[];
    uniforms?: Uniform<UniformData>[];
    viewport?: Viewport;
    mode?: number;
    indices?: Uint16Array;
    clear?: boolean;
}
/**
 * The type of objects the function returned by Shader can be called with.
 */
declare type RenderTarget = HTMLCanvasElement | TextureUniform<TextureData>;
/**
 * The type of function returned by Shader.
 */
declare type ShaderFunc = (target: RenderTarget) => RenderTarget;
/**
 * Create a shader function to render to a target.
 * @param vertexSrc the vertex shader source
 * @param fragmentSrc the fragment shader source
 * @param options for the shader
 */
export declare const Shader: (vertexSrc: string, fragmentSrc: string, options: ShaderOptions) => ShaderFunc;
export {};
